pyxmpp2.interfaces.StanzaPayload

Package pyxmpp2 :: Module interfaces :: Class StanzaPayload |
[hide private]

# Class StanzaPayload

Abstract base class for stanza payload objects.

Nested Classes | [hide private]
| __metaclass__ Metaclass for defining Abstract Base Classes (ABCs).

Instance Methods | [hide private]
__init__(self, element) x.__init__(...) initializes x; see help(type(x)) for signature |
`ElementTree.Element` |
as_xml(self) Return the XML representation of the payload. |
copy(self) Return a deep copy of self. |
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| __abstractmethods__ = ``frozenset([``])``
| _abc_cache = `<_weakrefset.WeakSet object at 0x85cae2c>`
| _abc_negative_cache = `<_weakrefset.WeakSet object at 0x85cae6c>`
| _abc_negative_cache_version = `10`
| _abc_registry = `<_weakrefset.WeakSet object at 0x85cadcc>`

Properties | [hide private]
| handler_key Defines a key which may be used when registering handlers for stanzas with this payload.
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, element) (Constructor) |
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)

Property Details | [hide private]

### handler_key Defines a key which may be used when registering handlers for stanzas with this payload. Get Method: unreachable.handler_key(self) - Defines a key which may be used when registering handlers for stanzas with this payload.